@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2015-03-22'; # DATE
-our $VERSION = '1.48'; # VERSION
+our $DATE = '2015-04-09'; # DATE
+our $VERSION = '1.49'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -193,6 +193,8 @@ sub BUILD {
                 my ($go, $val, $r) = @_;
                 $r->{format_options} = __json_decode($val);
             },
+            is_settable_via_config => 1,
+            tags => ['category:output'],
         };
 
         if ($self->subcommands) {
@@ -226,7 +228,6 @@ sub BUILD {
 
         if ($self->undo) {
             $copts->{history} = {
-                category => 'Undo options',
                 getopt  => 'history',
                 summary => N__('List actions history'),
                 handler => sub {
@@ -234,9 +235,9 @@ sub BUILD {
                     $r->{action} = 'history';
                     $r->{skip_parse_subcommand_argv} = 1;
                 },
+                tags => ['category:undo'],
             };
             $copts->{clear_history} = {
-                category => 'Undo options',
                 getopt  => "clear-history",
                 summary => N__('Clear actions history'),
                 handler => sub {
@@ -244,9 +245,9 @@ sub BUILD {
                     $r->{action} = 'clear_history';
                     $r->{skip_parse_subcommand_argv} = 1;
                 },
+                tags => ['category:undo'],
             };
             $copts->{undo} = {
-                category => 'Undo options',
                 getopt  => 'undo',
                 summary => N__('Undo previous action'),
                 handler => sub {
@@ -254,9 +255,9 @@ sub BUILD {
                     $r->{action} = 'undo';
                     $r->{skip_parse_subcommand_argv} = 1;
                 },
+                tags => ['category:undo'],
             };
             $copts->{redo} = {
-                category => 'Undo options',
                 getopt  => 'redo',
                 summary => N__('Redo previous undone action'),
                 handler => sub {
@@ -550,7 +551,7 @@ sub hook_after_run {
     $self->_unsetup_progress_output;
 }
 
-sub run_subcommands {
+sub action_subcommands {
     my ($self, $r) = @_;
 
     if (!$self->subcommands) {
@@ -603,7 +604,7 @@ sub run_subcommands {
      {"x.perinci.cmdline._skip_format"=>1}];
 }
 
-sub run_version {
+sub action_version {
     my ($self, $r) = @_;
 
     my $url = $r->{subcommand_data}{url} // $self->url;
@@ -630,7 +631,7 @@ sub run_version {
     ), {"x.perinci.cmdline._skip_format"=>1}];
 }
 
-sub run_call {
+sub action_call {
     my ($self, $r) = @_;
 
     my $scn = $r->{subcommand_name};
@@ -692,7 +693,7 @@ sub run_call {
     $res;
 }
 
-sub run_history {
+sub action_history {
     my ($self, $r) = @_;
     my $res = $self->riap_client->request(list_txs => "/", {detail=>1});
     $log->tracef("list_txs res=%s", $res);
@@ -714,17 +715,17 @@ sub run_history {
     [200, "OK", \@txs];
 }
 
-sub run_clear_history {
+sub action_clear_history {
     my ($self, $r) = @_;
     $self->riap_client->request(discard_all_txs => "/");
 }
 
-sub run_undo {
+sub action_undo {
     my ($self, $r) = @_;
     $self->riap_client->request(undo => "/");
 }
 
-sub run_redo {
+sub action_redo {
     my ($self, $r) = @_;
     $self->riap_client->request(redo => "/");
 }
@@ -744,7 +745,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.48 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-03-22.
+This document describes version 1.49 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-04-09.
 
 =head1 SYNOPSIS
 
