@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic::Role::Help;
 
-our $DATE = '2015-03-22'; # DATE
-our $VERSION = '1.48'; # VERSION
+our $DATE = '2015-04-09'; # DATE
+our $VERSION = '1.49'; # VERSION
 
 # split here just so it's more organized
 
@@ -419,7 +419,7 @@ sub help_section_links {
     # not yet
 }
 
-sub run_help {
+sub action_help {
     my ($self, $r) = @_;
 
     $r->{_help_buf} = '';
@@ -511,7 +511,7 @@ Perinci::CmdLine::Classic::Role::Help - Help-related routines
 
 =head1 VERSION
 
-This document describes version 1.48 of Perinci::CmdLine::Classic::Role::Help (from Perl distribution Perinci-CmdLine-Classic), released on 2015-03-22.
+This document describes version 1.49 of Perinci::CmdLine::Classic::Role::Help (from Perl distribution Perinci-CmdLine-Classic), released on 2015-04-09.
 
 =for Pod::Coverage ^(.+)$
 
